@@ -1,6 +1,7 @@
+from django.contrib.auth.backends import ModelBackend
 from django.contrib.auth.models import User
 
-class UrlCryptBackend:
+class UrlCryptBackend(ModelBackend):
     
     def authenticate(self, decoded_data=None):
         try:
@@ -12,4 +13,5 @@ class UrlCryptBackend:
         try:
             return User.objects.get(pk=user_id)
         except User.DoesNotExist:
-            return None
\ No newline at end of file
+            return None
+    
