@@ -1,7 +1,7 @@
 from django.conf.urls.defaults import *
-from django.conf import settings
+from urlcrypt.conf import RUNNING_TESTS
 
-if settings.RUNNING_TESTS:
+if RUNNING_TESTS:
     urlpatterns = patterns('urlcrypt.views',
         url(r'^test/view/$', 'test_view', name='urlcrypt_test_view'),  
         url(r'^test/view/(?P<username>.+)/$', 'test_view', name='urlcrypt_test_view_username'),  
@@ -10,5 +10,5 @@ else:
     urlpatterns = patterns('')
 
 urlpatterns += patterns('urlcrypt.views',
-    url(r'^(?P<token>.+)/$', 'login_redirect', name='urlcrypt_redirect'),  
+    url(r'^(?P<token>.+)/$', 'login_redirect', name='urlcrypt_redirect'),
 ) 
\ No newline at end of file
